/**
 * GMyth Library
 *
 * @file gmyth/gmyth_http.c
 * 
 * @brief <p> GMythHttp class provides a wrapper to access
 * data from the database using http+xml
 *
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Artur Duque de Souza <@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __GMYTH_HTTP_H__
#define __GMYTH_HTTP_H__

#include <glib-object.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>
#include <glib.h>
#include <glib/gprintf.h>

#include "gmyth_backendinfo.h"
#include "gmyth_util.h"

#include <curl/curl.h>
#include <curl/types.h>
#include <curl/easy.h>

G_BEGIN_DECLS

#define MYTH_PORT_STATUS 6544
#define BUFLEN 2048

typedef struct _GMythPacket     GMythPacket;
typedef struct _GMythProgram    GMythProgram;
typedef struct _GMythChannel	GMythChannel;
typedef struct _GMythEpg		GMythEpg;

struct _GMythPacket
{
    GString *response;
    int    type;
};

struct _GMythProgram
{
    GString* title;
	GString* subtitle;
	GString* catType;
    GString* category;
	gint	repeat;
	GTimeVal* startTime;
	GTimeVal* endTime;
};

//gmyth_util_string_to_time_val ( const gchar* time_str )

struct _GMythChannel
{
	GString* channelName;
	GString* chanNum;
	gint	chanId;
	gint	callSign;
	GSList*	programList;
};

struct _GMythEpg
{
	gint startChanId;
	gint endChanId;
	GString* version;
	gint protoVer;
	gint totalCount;
	gint numOfChannels;
	GTimeVal* asOf;
	GTimeVal* startTime;
	GTimeVal* endTime;
	gint details;
	GSList* channelList;
};

GString* gmyth_http_create_command(GString *command, ...);
GString *gmyth_http_request (GMythBackendInfo *backend_info, GString *command);

G_END_DECLS

#endif /* __GMYTH_HTTP_H__ */
